#include <services/services.h>
#include <services/fss/adi_fss.h>

#define OPT
#include "def.h"
#include "string.h"
#include "stdio.h"

static void work(void *pHandle, u32 Event, void *pArg);
/*******************************************************************
* Device Driver headers
*   Add all relevant headers
*******************************************************************/

/* File Sytem Drivers */
#define _ADI_FAT_DEFAULT_DEF_
#include <drivers/fsd/fat/adi_fat.h>

/* ATAPI interface */
#define _ADI_ATAPI_DEFAULT_DEF_
#include <drivers/pid/atapi/adi_atapi.h>

/* USB interface */
#define _ADI_USB_DEFAULT_DEF_
#include <drivers/pid/usb/adi_usb.h>

/* DMA and Device Manager Handles */
#include <heapinfo.h>
#include "adi_ssl_init.h"
/* FSS General Heap Defined on a page boundary in the LDF
*/
extern "asm" int FssGeneralHeap;
extern "asm" int FssGeneralHeap_length;

void InitFileSystem(void)
{

    /*******************************************************************
    * Customized heaps for General, fat and atapi 'cache' type data  define at the ldf 
    *******************************************************************/
	/*******************************************************************
    * Customized heaps for General and driver DMA buffers
    *******************************************************************/
    int GeneralHeapID = heap_install (&FssGeneralHeap, (size_t)&FssGeneralHeap_length, 1);
    

    /*******************************************************************
    * command table for the FAT driver
    *******************************************************************/
    static ADI_DEV_CMD_VALUE_PAIR ADI_FAT_ConfigTable [] = {
            { ADI_FSS_CMD_SET_CACHE_HEAP_ID,   (void*)0 },
            { ADI_DEV_CMD_END,                 NULL     },
    };
    ADI_FAT_ConfigTable[0].Value = (void*)GeneralHeapID;
	
    /*******************************************************************
    * Configuration table to initialize the FSS
    *******************************************************************/
    ADI_FSS_CMD_VALUE_PAIR adi_fss_Config[] = 
    {
        { ADI_FSS_CMD_SET_NUMBER_CACHE_BLOCKS,      (void*)4                        },
        { ADI_FSS_CMD_SET_NUMBER_CACHE_SUB_BLOCKS,  (void*)1                        },
		/////HeapID parameter passed into the fss

        { ADI_FSS_CMD_SET_GENERAL_HEAP_ID,          (void*)GeneralHeapID            },
        
        { ADI_FSS_CMD_ADD_DRIVER,                   (void*)&ADI_USB_Def             },
      //  { ADI_FSS_CMD_ADD_DRIVER,                   (void*)&ADI_ATAPI_Def           },

        /* Add File Systems - one command per type of File System Present */
        { ADI_FSS_CMD_ADD_DRIVER,                   (void*)&ADI_FAT_Def             },
        
        /* DMA and Device Manager Handles */
        { ADI_FSS_CMD_SET_DMA_MGR_HANDLE,           (void*)adi_dma_ManagerHandle    },
        { ADI_FSS_CMD_SET_DEV_MGR_HANDLE,           (void*)adi_dev_ManagerHandle    },
        
        /* Command Table Terminator */
        { ADI_FSS_CMD_END,                          (void*)NULL                     }
    };
    
   
    /* Initialise the file system service */
    adi_fss_Init ( adi_fss_Config );
	
    
    /* Add to CRT device table - which will make it the default */
    add_devtab_entry( &adi_fss_entry );
    
    
    
    //extern 
	
}

unsigned int ListDirectory( char *dirname, int dirtype )
{
	unsigned int i, Result = ADI_FSS_RESULT_SUCCESS;
    struct dirent *pDirEntry;
    char str[80];
    	
	DIR *pDir = opendir(dirname);
	if (pDir) 
	{
		i = 0;		
		do 
		{
			pDirEntry = readdir(pDir);
			/* Generate directory lising including files and sub-directories */
		 	if (pDirEntry)
		    {
		    	if (pDirEntry->d_type == DT_DIR)
	    		diskList.flist[i].type = FILETYPE_DIRECTORY;
				else
	    		diskList.flist[i].type = FILETYPE_FILE;
	    		
				diskList.flist[i].size = pDirEntry->d_size;
	    
				strftime(str,80,"%b %d %Y %H:%M:%S",&pDirEntry->DateModified);
				strncpy (diskList.flist[i].date,str,80);
				strncpy (diskList.flist[i].entryname,pDirEntry->d_name,80);
				i++;
		    }
    
		} while (pDirEntry);
		
		diskList.indexnum = i;
	
		closedir(pDir);
	} 
	else 
	{
		Result = ADI_FSS_RESULT_FAILED;
	}
	
		return Result;
}





