/*******************************************************************
Analog Devices, Inc. All Rights Reserved.

This software is proprietary and confidential.  By using this software
you agree to the terms of the associated Analog Devices License Agreement.

Project Name:  	Power_On_Self_Test

Hardware:		ADSP-BF527 EZ-KIT Lite

Description:	This examples performs POST on the BF527 EZ-Kit Lite
*******************************************************************/

#include <cdefBF527.h>
#include <ccblkfn.h>
#include <bfrom.h>
#include "Pll.h"

// NEED TO CHECK THE REV CODE AT 0xEF000040
// 0xAD020101 on BF527 0.0
// 0xAD020102 on BF527 0.1
// 0xAD020301 on BF527 0.2
#define pRev ((volatile unsigned long *)0xEF000040)

/*******************************************************************
*   Function:    TEST_VERSION
*   Description: This function compares the version of the processor
* 				 being run on with the version that the software was
*				 built against
*******************************************************************/
int TEST_VERSION(void)
{
	int j = *pDSPID;
	int k = __SILICON_REVISION__;
	int i = *pRev;
	int Rev;
	
	if( *pRev == 0xAD020101 )
		Rev = 0x0;
	else if( *pRev == 0xAD020102 )
		Rev = 0x1;
	else if( *pRev == 0xAD020301 )
		Rev = 0x2;
	else
		Rev = 0xBAADF00D;

	if( __SILICON_REVISION__ != Rev )
	{
		return 0; // failed
	}

	return 1; // passed
}

/*******************************************************************
*   Function:    Get_Silicon_Rev
*   Description: This function returns the silicon revision
*******************************************************************/
int Get_Silicon_Rev(unsigned short *usRev)
{
	int j = *pDSPID;
	int k = __SILICON_REVISION__;
	int i = *pRev;
	
	if( *pRev == 0xAD020101 )
		*usRev = 0x0;
	else if( *pRev == 0xAD020102 )
		*usRev = 0x1;
	else if( *pRev == 0xAD020301 )
		*usRev = 0x2;
	else
		*usRev = 0xFFFF;

	return 1; // passed
}
/*******************************************************************
*   Function:    Init_PLL
*   Description: initializes the PLL registers
*******************************************************************/
void Init_PLL(unsigned int msel, unsigned int ssel)
{	
	unsigned short usRev=0;
	
	Get_Silicon_Rev(&usRev);
	if(usRev<2)
	{
	
	*pSIC_IWR0 |= 0x1;			/* enable PLL wakeup */
	*pPLL_CTL = SET_MSEL(msel);	/* 25MHz Xtal x MSEL = CCLK		*/

	idle();

	*pPLL_DIV = SET_SSEL(ssel);	/* CCLK/SSEL = SCLK	
				*/
//	ssync();
	}else
	{
    	// silicon revisions of 0.2 and greater should now use
    	// bfrom_SysControl to change the PLL.
    	ADI_SYSCTRL_VALUES sys_cntrl_struct;

		sys_cntrl_struct.uwPllCtl = (msel<<9);
		sys_cntrl_struct.uwPllDiv = ssel;

		bfrom_SysControl( SYSCTRL_WRITE | SYSCTRL_PLLCTL | SYSCTRL_PLLDIV,
						   &sys_cntrl_struct, NULL);
		
	}
}

